SelectionDialog class

selection dialog used for selection of the country code

Inheritance

Constructors

SelectionDialog(List<CountryCode> elements, List<CountryCode> favoriteElements, {Key? key, bool? showCountryOnly, WidgetBuilder? emptySearchBuilder, InputDecoration searchDecoration = const InputDecoration(), TextStyle? searchStyle, TextStyle? textStyle, BoxDecoration? boxDecoration, bool? showFlag, Decoration? flagDecoration, double flagWidth = 32, Size? size, Color? backgroundColor, Color? barrierColor, bool hideSearch = false, Widget searchBuilder(BuildContext context, dynamic onChange(String))?, Icon? closeIcon})

Properties

backgroundColor → Color?
Background color of SelectionDialog
final
barrierColor → Color?
Boxshaow color of SelectionDialog that matches CountryCodePicker barrier color
final
boxDecoration → BoxDecoration?
final
closeIcon → Icon?
final
elements → List<CountryCode>
final
emptySearchBuilder → WidgetBuilder?
final
favoriteElements → List<CountryCode>
elements passed as favorite
final
flagDecoration → Decoration?
final
flagWidth → double
final
hashCode → int
The hash code for this object.
no setterinherited
hideSearch → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchBuilder → Widget Function(BuildContext context, dynamic onChange(String))?
While using searchBuilder, hideSearch should be set to false. You will get a BuildContext context instance, Function(String) onChange function as callback arguments. Make to assign the onChange function to the onChanged property of the TextField widget. This will enable the filteration logic.
final
searchDecoration → InputDecoration
final
searchStyle → TextStyle?
final
showCountryOnly → bool?
final
showFlag → bool?
final
size → Size?
final
textStyle → TextStyle?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited